Struct openssl::x509::extension::AuthorityKeyIdentifier [−][src]
pub struct AuthorityKeyIdentifier { /* fields omitted */ }Expand description
An extension that provides a means of identifying the public key corresponding to the private key used to sign a CRL.
Implementations
Construct a new AuthorityKeyIdentifier extension.
Sets the critical flag to true. The extension will be critical.
Sets the keyid flag.
Sets the issuer flag.
Return a AuthorityKeyIdentifier extension as an X509Extension.