Struct openssl::x509::extension::BasicConstraints [−][src]
pub struct BasicConstraints { /* fields omitted */ }Expand description
An extension which indicates whether a certificate is a CA certificate.
Implementations
Construct a new BasicConstraints extension.
Sets the critical flag to true. The extension will be critical.
Sets the ca flag to true.
Sets the pathlen to an optional non-negative value. The pathlen is the maximum number of CAs that can appear below this one in a chain.
Return the BasicConstraints extension as an X509Extension.